@@ -20,7 +20,7 @@
  * USA
  *
  * --------------------------------------------------------------------------
- * $Id: JadortServiceTest.java 5656 2009-11-30 17:12:08Z alitokmen $
+ * $Id: JadortServiceTest.java 5667 2009-12-02 10:10:51Z alitokmen $
  * --------------------------------------------------------------------------
  */
 package org.ow2.jasmine.jadort.tests.implementation;
@@ -847,6 +847,10 @@ public class JadortServiceTest {
         System.out.println("JadortServiceTest.testDeployOsgiBundle");
 
         this.deployOsgiBundle("src/test/resources/service-alerte-1.0.0-SNAPSHOT/service-alerte.jar");
+
+        // Change page
+        this.jadortService.next();
+        Assert.assertEquals(Step.FINISHED, this.jadortService.getCurrentOperation().getCurrentStep());
         Assert.assertNull(this.jadortService.getCurrentOperation().getServerProgressList().iterator().next()
             .getOldDeploymentItem());
     }
@@ -859,6 +863,16 @@ public class JadortServiceTest {
         System.out.println("JadortServiceTest.testDeployNewVersionOfOsgiBundle");
 
         this.deployOsgiBundle("src/test/resources/service-alerte-1.0.0/service-alerte.jar");
+
+        // Erase old version
+        this.jadortService.next();
+        Assert.assertEquals(Step.ERASE_OLD_VERSIONS, this.jadortService.getCurrentOperation().getCurrentStep());
+        this.jadortService.next();
+        this.waitForFinishAndCheckServerProgressList(ServerProgressState.ERASE_OK, 100);
+
+        // Change page
+        this.jadortService.next();
+        Assert.assertEquals(Step.FINISHED, this.jadortService.getCurrentOperation().getCurrentStep());
         Assert.assertNotNull(this.jadortService.getCurrentOperation().getServerProgressList().iterator().next()
             .getOldDeploymentItem());
     }
@@ -882,11 +896,22 @@ public class JadortServiceTest {
         Assert.assertEquals(Step.EXECUTING_MIGRATION_OSGI, this.jadortService.getCurrentOperation().getCurrentStep());
         this.waitForFinishAndCheckServerProgressList(ServerProgressState.INITIAL, 0);
 
-        this.executeOsgiMigration();
-
-        // Change page
+        // Upload bundle
         this.jadortService.next();
-        Assert.assertEquals(Step.FINISHED, this.jadortService.getCurrentOperation().getCurrentStep());
+        Assert.assertEquals(Step.EXECUTING_MIGRATION_OSGI, this.jadortService.getCurrentOperation().getCurrentStep());
+        this.waitForFinishAndCheckServerProgressList(ServerProgressState.UPLOAD_OK, 33);
+
+        // Undeploy old version
+        this.jadortService.next();
+        Assert.assertEquals(Step.EXECUTING_MIGRATION_OSGI, this.jadortService.getCurrentOperation().getCurrentStep());
+        this.waitForFinishAndCheckServerProgressList(ServerProgressState.UNDEPLOY_OK, 66);
+
+        // Deploy bundle
+        this.jadortService.next();
+        Assert.assertEquals(Step.EXECUTING_MIGRATION_OSGI, this.jadortService.getCurrentOperation().getCurrentStep());
+        this.waitForFinishAndCheckServerProgressList(ServerProgressState.DEPLOY_OK, 100);
+
+        Assert.assertEquals(Step.EXECUTING_MIGRATION_OSGI, this.jadortService.getCurrentOperation().getCurrentStep());
     }
 
     private void executeMigration() throws Exception {
@@ -909,32 +934,6 @@ public class JadortServiceTest {
         Assert.assertEquals(Step.EXECUTING_MIGRATION, this.jadortService.getCurrentOperation().getCurrentStep());
     }
 
-    private void executeOsgiMigration() throws Exception {
-        System.out.println("\tJadortServiceTest.executeOsgiMigration");
-
-        // Upload bundle
-        this.jadortService.next();
-        Assert.assertEquals(Step.EXECUTING_MIGRATION_OSGI, this.jadortService.getCurrentOperation().getCurrentStep());
-        this.waitForFinishAndCheckServerProgressList(ServerProgressState.UPLOAD_OK, 25);
-
-        // Undeploy old version
-        this.jadortService.next();
-        Assert.assertEquals(Step.EXECUTING_MIGRATION_OSGI, this.jadortService.getCurrentOperation().getCurrentStep());
-        this.waitForFinishAndCheckServerProgressList(ServerProgressState.UNDEPLOY_OK, 50);
-
-        // Deploy bundle
-        this.jadortService.next();
-        Assert.assertEquals(Step.EXECUTING_MIGRATION_OSGI, this.jadortService.getCurrentOperation().getCurrentStep());
-        this.waitForFinishAndCheckServerProgressList(ServerProgressState.DEPLOY_OK, 75);
-
-        // Erase old version
-        this.jadortService.next();
-        Assert.assertEquals(Step.EXECUTING_MIGRATION_OSGI, this.jadortService.getCurrentOperation().getCurrentStep());
-        this.waitForFinishAndCheckServerProgressList(ServerProgressState.ERASE_OK, 100);
-
-        Assert.assertEquals(Step.EXECUTING_MIGRATION_OSGI, this.jadortService.getCurrentOperation().getCurrentStep());
-    }
-
     private void undeployEraseOldVersion(final boolean eraseOld) throws Exception {
         System.out.println("\tJadortServiceTest.undeployEraseOldVersion");
 
